'use strict';
var ipRangeCheck = require('ip-range-check');

var RFC_1918_NETWORKS = [
  '127.0.0.0/8',
  '10.0.0.0/8',
  '172.16.0.0/12',
  '192.168.0.0/16'
];

var RFC_6890_NETWORKS = [
  '0.0.0.0/8',         //  "This" Network [RFC1700, page 4]
  '100.64.0.0/10',     //  Shared address space [6598, 6890]
  //'128.0.0.0/16',      //  Reserved in 3330, not in 6890, has been assigned
  '169.254.0.0/16',    //  Link Local [3927, 6890]
  //'191.255.0.0/16'     //  Reserved in 3330, not in 6890, has been assigned
  '192.0.0.0/24',      //  Reserved but subject to allocation [6890]
  '192.0.0.0/29',      //  DS-Lite                        [6333, 6890]. Redundant with above, included for completeness.
  '192.0.2.0/24',      //  Documentation                  [5737, 6890]
  '192.88.99.0/24',    //  6to4 Relay Anycast             [3068, 6890]
  '198.18.0.0/15',     //  Network Interconnect Device Benchmark Testing [2544, 6890]
  '198.51.100.0/24',   //  Documentation                  [5737, 6890]
  '203.0.113.0/24',    //  Documentation                  [5737, 6890]
  '224.0.0.0/4',       //  Multicast                      [11112]
  '240.0.0.0/4',       //  Reserved for Future Use        [6890]
  '255.255.255.255/32', //  Reserved for Future Use        [6890]
  '::/128',            //  Unspecified address
  '::1/128',           //  Loopback
  '::ffff:0:0/96',     //  IPv4 mapped addresses
  '100::/64',          //  Discard Prefix                 [6666]
  '64:ff9b::/96',      //  IPv4/IPv6 transition           [6052]
  '2001::/32',         //  Teredo tunneling
  '2001:10::/28',      //  Deprecated ORCHID
  '2001:20::/28',      //  ORCHIDv2
  '2001:db8::/32',     //  Documentation
  '2002::/16',         //  6to4
  'fc00::/7',          //  Unique local address
  'fe80::/10',         //  Link-local address
  'ff00::/8'           //  Multicast
];

function isRFC1918(ip) {
  return ipRangeCheck(ip, RFC_1918_NETWORKS);
}

function isRFC6890(ip) {
  return ipRangeCheck(ip, RFC_6890_NETWORKS);
}

function isDenied(ip) {
  return isRFC1918(ip) || isRFC6890(ip);
}

module.exports = {
  isDenied: isDenied,
  isRFC1918: isRFC1918,
  isRFC6890: isRFC6890
};
